@@ -9,7 +9,6 @@ import re
 import sys
 import types
 import urllib.parse
-from contextlib import contextmanager
 from fnmatch import fnmatchcase
 from pathlib import Path
 from typing import Any, Callable, Generator, Iterable, Match
@@ -106,16 +105,6 @@ def find_packages_iter(
             dirs.append(dir)
 
 
-@contextmanager
-def cd(path: str | Path) -> Generator[None, None, None]:
-    _old_cwd = os.getcwd()
-    os.chdir(path)
-    try:
-        yield
-    finally:
-        os.chdir(_old_cwd)
-
-
 def normalize_path(filename: str | Path) -> str:
     """Normalize a file/dir name for comparison purposes"""
     filename = os.path.abspath(filename) if sys.platform == "cygwin" else filename
@@ -152,14 +141,18 @@ def expand_vars(line: str, root: str) -> str:
 
 
 def import_module_at_path(
-    src_path: str | Path, module_name: str = "_local"
+    src_path: str | Path, module_name: str = "_local", context: Path | None = None
 ) -> types.ModuleType:
     """Import a module from a given path."""
     spec = importlib.util.spec_from_file_location(module_name, src_path)
     if spec is None:
         raise ValueError(f"Could not import module {module_name} from {src_path}")
+    if context is not None:
+        sys.path.insert(0, str(context.absolute()))
     module = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(module)  # type: ignore
+    if context is not None:
+        sys.path.pop(0)
     return module
 
 
@@ -179,7 +172,7 @@ def normalize_file_permissions(st_mode: int) -> int:
 
 
 @contextlib.contextmanager
-def patch_sys_path(path: str | Path) -> Generator[None, None, None]:
+def patch_sys_path(path: str | Path) -> Generator[None]:
     old_path = sys.path[:]
     sys.path.insert(0, str(path))
     try:
